# indic-trans

This is an adaptation from the wonderful work by Irshad Ahmad Bhat
* `Official source code repo <https://github.com/libindic/indic-trans>`_

## Changes

- code is changed mainly to make a pip installable package.
- there is a cli program to test 
- loading is simplified

## Installing

```
pip install indictrans
```

## Basic Program

```
indictrans-cli -x
```

## Cite

Citation for the original work is:

@inproceedings{Bhat:2014:ISS:2824864.2824872,
 author = {Bhat, Irshad Ahmad and Mujadia, Vandan and Tammewar, Aniruddha and Bhat, Riyaz Ahmad and Shrivastava, Manish},
 title = {IIIT-H System Submission for FIRE2014 Shared Task on Transliterated Search},
 booktitle = {Proceedings of the Forum for Information Retrieval Evaluation},
 series = {FIRE '14},
 year = {2015},
 isbn = {978-1-4503-3755-7},
 location = {Bangalore, India},
 pages = {48--53},
 numpages = {6},
 url = {http://doi.acm.org/10.1145/2824864.2824872},
 doi = {10.1145/2824864.2824872},
 acmid = {2824872},
 publisher = {ACM},
 address = {New York, NY, USA},
 keywords = {Information Retrieval, Language Identification, Language Modeling, Perplexity, Transliteration},
}
